==> lxqt-l10n_0.12.0.orig.tar.xz: lxqt-l10n-0.12.0/lxqt-powermanagement/lxqt-powermanagement/lxqt-powermanagement_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>BatteryHelper</name>
    <message>
        <location filename="../../../batteryhelper.cpp" line="42"/>
        <source>Empty</source>
        <translation>Üres</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="44"/>
        <source>Discharging</source>
        <translation>Kisütés</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="46"/>
        <source>Fully charged</source>
        <translation>Teletöltve</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="49"/>
        <source>Charging</source>
        <translation>Töltés</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="58"/>
        <source>Lithium ion</source>
        <translation>Lítium ion</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="60"/>
        <source>Lithium polymer</source>
        <translation>Lítium polimer</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="62"/>
        <source>Lithium iron phosphate</source>
        <translation>Lítium vasfoszfát</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="64"/>
        <source>Lead acid</source>
        <translation>Savas ólom</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="66"/>
        <source>Nickel cadmium</source>
        <translation>Nikkel kadmium</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="68"/>
        <source>Nickel metal hydride</source>
        <translation>Nikkel fémhibrid</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="71"/>
        <source>Unknown</source>
        <translation>Ismeretlen</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="80"/>
        <source>Personal Digital Assistant&apos;s battery</source>
        <translation>PDA táp</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="82"/>
        <source>Uninterruptible Power Supply&apos;s battery</source>
        <translation>Folytonos táp</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="84"/>
        <source>Primary battery</source>
        <translation>Elsődleges táp</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="86"/>
        <source>Mouse battery</source>
        <translation>Egér táp</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="88"/>
        <source>Keyboard battery</source>
        <translation>Bellentyűzet táp</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="90"/>
        <source>Keyboard and mouse&apos;s battery</source>
        <translation>Billentyű és egértáp</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="92"/>
        <source>Camera battery</source>
        <translation>Kamera táp</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="94"/>
        <source>Phone battery</source>
        <translation>Telefon táp</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="96"/>
        <source>Monitor battery</source>
        <translation>Monitor táp</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="99"/>
        <source>Unknown battery</source>
        <translation>Ismeretlen táp</translation>
    </message>
</context>
<context>
    <name>BatteryInfoDialog</name>
    <message>
        <location filename="../../../batteryinfodialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>Párbeszéd</translation>
    </message>
    <message>
        <location filename="../../../batteryinfodialog.cpp" line="22"/>
        <source>Battery Info</source>
        <translation>Akku infó</translation>
    </message>
</context>
<context>
    <name>BatteryInfoFrame</name>
    <message>
        <location filename="../../../batteryinfoframe.ui" line="14"/>
        <source>Power Management</source>
        <translation>Energiakezelés</translation>
    </message>
    <message>
        <location filename="../../../batteryinfoframe.ui" line="53"/>
        <source>Temperature:</source>
        <translation>Hőfok:</translation>
    </message>
    <message>
        <location filename="../../../batteryinfoframe.ui" line="63"/>
        <source>Type:</source>
        <translation>Típus:</translation>
    </message>
    <message>
        <location filename="../../../batteryinfoframe.ui" line="73"/>
        <source>State:</source>
        <translation>Állapot:</translation>
    </message>
    <message>
        <location filename="../../../batteryinfoframe.ui" line="90"/>
        <source>Energy Full Design:</source>
        <translation>Névleges kapacitás:</translation>
    </message>
    <message>
        <location filename="../../../batteryinfoframe.ui" line="107"/>
        <source>Energy Full:</source>
        <translation>Teljes kapacitás:</translation>
    </message>
    <message>
        <location filename="../../../batteryinfoframe.ui" line="124"/>
        <source>Energy Now:</source>
        <translation>Mostani kapacitás:</translation>
    </message>
    <message>
        <location filename="../../../batteryinfoframe.ui" line="141"/>
        <source>Energy rate:</source>
        <translation>Átlagos teljesítmény:</translation>
    </message>
    <message>
        <location filename="../../../batteryinfoframe.ui" line="165"/>
        <source>Technology:</source>
        <translation>Technológia:</translation>
    </message>
    <message>
        <location filename="../../../batteryinfoframe.ui" line="182"/>
        <source>Voltage:</source>
        <translation>Feszültség:</translation>
    </message>
    <message>
        <location filename="../../../batteryinfoframe.ui" line="192"/>
        <source>Vendor:</source>
        <translation>Gyártó:</translation>
    </message>
</context>
<context>
    <name>BatteryWatcher</name>
    <message>
        <location filename="../../../batterywatcher.cpp" line="47"/>
        <source>No battery!</source>
        <translation>Nincs akku!</translation>
    </message>
    <message>
        <location filename="../../../batterywatcher.cpp" line="48"/>
        <source>LXQt could not find data about any battery - monitoring disabled</source>
        <translation>Az LXQt nem ismert fel akkut - figyelés tiltva</translation>
    </message>
    <message>
        <location filename="../../../batterywatcher.cpp" line="113"/>
        <source>Power low!</source>
        <translation>Alacsony feszültség!</translation>
    </message>
    <message numerus="yes">
        <location filename="../../../batterywatcher.cpp" line="125"/>
        <source>Suspending in %n second(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../../../batterywatcher.cpp" line="128"/>
        <source>Hibernating in %n second(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../../../batterywatcher.cpp" line="131"/>
        <source>Shutting down in %n second(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Suspending in %1 seconds</source>
        <translation type="vanished">%1 másodperc múlva készülség</translation>
    </message>
    <message>
        <source>Hibernating in %1 seconds</source>
        <translation type="vanished">%1 másodperc múlva mélykészenlét</translation>
    </message>
    <message>
        <source>Shutting down in %1 seconds</source>
        <translation type="vanished">%1 másodperc múlva kikapcsolás</translation>
    </message>
</context>
<context>
    <name>IdlenessWatcher</name>
    <message>
        <source>LXQt Idleness watcher failed to start</source>
        <translation type="vanished">Az LXQt tétlenség figyelő indítása sikertelen</translation>
    </message>
    <message>
        <source>D-Bus interface org.freedesktop.ScreenSaver is already registered</source>
        <translation type="vanished">A D-Bus interface org.freedesktop.ScreenSaver imár regisztrálva van</translation>
    </message>
    <message>
        <source>The X11 Screensaver extension is not usable</source>
        <translation type="vanished">Az X11 képernyővédő bővítmény használhatatlan</translation>
    </message>
    <message>
        <source>Configure...</source>
        <translation type="vanished">Beállítás...</translation>
    </message>
    <message>
        <source>ERROR: Screen unlocked</source>
        <translation type="vanished">HIBA: A képernyő nem zárolt</translation>
    </message>
    <message>
        <source>Locking program &quot;%1&quot; exited with error code %2</source>
        <translation type="vanished">A&quot;%1&quot; zároló program %2 hibakóddal kilépett</translation>
    </message>
    <message>
        <source>Locking program &quot;%1&quot; crashed with error code %2</source>
        <translation type="vanished">A&quot;%1&quot; zároló program %2 hibakóddal összeomlott</translation>
    </message>
</context>
<context>
    <name>PowerManagementd</name>
    <message>
        <location filename="../../../powermanagementd.cpp" line="108"/>
        <source>Power Management</source>
        <translation>Energiakezelés</translation>
    </message>
    <message>
        <location filename="../../../powermanagementd.cpp" line="109"/>
        <source>You are running LXQt Power Management for the first time.
You can configure it from settings... </source>
        <translation>Az LXQt energiakezelő első alkalommal fut.
A beállításokban konfigurálható...</translation>
    </message>
    <message>
        <location filename="../../../powermanagementd.cpp" line="110"/>
        <source>Configure...</source>
        <translation>Beállítás...</translation>
    </message>
</context>
<context>
    <name>TrayIcon</name>
    <message>
        <location filename="../../../trayicon.cpp" line="59"/>
        <source>Configure</source>
        <translation>Beállítás</translation>
    </message>
    <message>
        <location filename="../../../trayicon.cpp" line="61"/>
        <location filename="../../../trayicon.cpp" line="92"/>
        <source>About</source>
        <translation>Rólunk</translation>
    </message>
    <message>
        <location filename="../../../trayicon.cpp" line="63"/>
        <source>Disable icon</source>
        <translation>Ikon tiltása</translation>
    </message>
    <message>
        <location filename="../../../trayicon.cpp" line="93"/>
        <source>&lt;p&gt;  &lt;b&gt;LXQt Power Management&lt;/b&gt;&lt;br/&gt;  - Power Management for the LXQt Desktop Environment&lt;/p&gt;&lt;p&gt;  Authors:&lt;br/&gt;  &amp;nbsp; Christian Surlykke, Alec Moskvin&lt;br/&gt;  &amp;nbsp; - and others from the Razor and LXQt projects&lt;/p&gt;&lt;p&gt;  Copyright &amp;copy; 2012-2014&lt;/p&gt;</source>
        <translation>&lt;p&gt;  &lt;b&gt;LXQt Power Management&lt;/b&gt;&lt;br/&gt;  - Energiakezelő az LXQt asztali környezethez&lt;/p&gt;&lt;p&gt;  Szerzők:&lt;br/&gt;  &amp;nbsp; Christian Surlykke, Alec Moskvin&lt;br/&gt;  &amp;nbsp; - és mások a Razor és LXQt csapatból&lt;/p&gt;&lt;p&gt;  Copyright &amp;copy; 2012-2014&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../../../trayicon.cpp" line="111"/>
        <source>LXQt Power Management info</source>
        <translation>LXQt Power Management infó</translation>
    </message>
    <message>
        <location filename="../../../trayicon.cpp" line="112"/>
        <source>The LXQt Power Management tray icon can be (re)enabled in &lt;i&gt;lxqt-config-powermanagement&lt;/i&gt;</source>
        <translation>Az LXQt energiakezelő tálcaikon (újra)engedélyezhető az &lt;i&gt;lxqt-config-powermanagement&lt;/i&gt; segítségével</translation>
    </message>
    <message>
        <location filename="../../../trayicon.cpp" line="114"/>
        <source>Configure now</source>
        <translation>Beállítás</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.13.0.orig.tar.xz: lxqt-l10n-0.13.0/lxqt-powermanagement/lxqt-powermanagement/lxqt-powermanagement_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>BatteryHelper</name>
    <message>
        <location filename="../../../batteryhelper.cpp" line="42"/>
        <source>Empty</source>
        <translation>Üres</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="44"/>
        <source>Discharging</source>
        <translation>Kisütés</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="46"/>
        <source>Fully charged</source>
        <translation>Teletöltve</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="49"/>
        <source>Charging</source>
        <translation>Töltés</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="58"/>
        <source>Lithium ion</source>
        <translation>Lítium ion</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="60"/>
        <source>Lithium polymer</source>
        <translation>Lítium polimer</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="62"/>
        <source>Lithium iron phosphate</source>
        <translation>Lítium vasfoszfát</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="64"/>
        <source>Lead acid</source>
        <translation>Savas ólom</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="66"/>
        <source>Nickel cadmium</source>
        <translation>Nikkel kadmium</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="68"/>
        <source>Nickel metal hydride</source>
        <translation>Nikkel fémhibrid</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="71"/>
        <source>Unknown</source>
        <translation>Ismeretlen</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="80"/>
        <source>Personal Digital Assistant&apos;s battery</source>
        <translation>PDA táp</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="82"/>
        <source>Uninterruptible Power Supply&apos;s battery</source>
        <translation>Folytonos táp</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="84"/>
        <source>Primary battery</source>
        <translation>Elsődleges táp</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="86"/>
        <source>Mouse battery</source>
        <translation>Egér táp</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="88"/>
        <source>Keyboard battery</source>
        <translation>Bellentyűzet táp</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="90"/>
        <source>Keyboard and mouse&apos;s battery</source>
        <translation>Billentyű és egértáp</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="92"/>
        <source>Camera battery</source>
        <translation>Kamera táp</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="94"/>
        <source>Phone battery</source>
        <translation>Telefon táp</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="96"/>
        <source>Monitor battery</source>
        <translation>Monitor táp</translation>
    </message>
    <message>
        <location filename="../../../batteryhelper.cpp" line="99"/>
        <source>Unknown battery</source>
        <translation>Ismeretlen táp</translation>
    </message>
</context>
<context>
    <name>BatteryInfoDialog</name>
    <message>
        <location filename="../../../batteryinfodialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>Párbeszéd</translation>
    </message>
    <message>
        <location filename="../../../batteryinfodialog.cpp" line="22"/>
        <source>Battery Info</source>
        <translation>Akku infó</translation>
    </message>
</context>
<context>
    <name>BatteryInfoFrame</name>
    <message>
        <location filename="../../../batteryinfoframe.ui" line="14"/>
        <source>Power Management</source>
        <translation>Energiakezelés</translation>
    </message>
    <message>
        <location filename="../../../batteryinfoframe.ui" line="53"/>
        <source>Temperature:</source>
        <translation>Hőfok:</translation>
    </message>
    <message>
        <location filename="../../../batteryinfoframe.ui" line="63"/>
        <source>Type:</source>
        <translation>Típus:</translation>
    </message>
    <message>
        <location filename="../../../batteryinfoframe.ui" line="73"/>
        <source>State:</source>
        <translation>Állapot:</translation>
    </message>
    <message>
        <location filename="../../../batteryinfoframe.ui" line="90"/>
        <source>Energy Full Design:</source>
        <translation>Névleges kapacitás:</translation>
    </message>
    <message>
        <location filename="../../../batteryinfoframe.ui" line="107"/>
        <source>Energy Full:</source>
        <translation>Teljes kapacitás:</translation>
    </message>
    <message>
        <location filename="../../../batteryinfoframe.ui" line="124"/>
        <source>Energy Now:</source>
        <translation>Mostani kapacitás:</translation>
    </message>
    <message>
        <location filename="../../../batteryinfoframe.ui" line="141"/>
        <source>Energy rate:</source>
        <translation>Átlagos teljesítmény:</translation>
    </message>
    <message>
        <location filename="../../../batteryinfoframe.ui" line="165"/>
        <source>Technology:</source>
        <translation>Technológia:</translation>
    </message>
    <message>
        <location filename="../../../batteryinfoframe.ui" line="182"/>
        <source>Voltage:</source>
        <translation>Feszültség:</translation>
    </message>
    <message>
        <location filename="../../../batteryinfoframe.ui" line="192"/>
        <source>Vendor:</source>
        <translation>Gyártó:</translation>
    </message>
</context>
<context>
    <name>BatteryWatcher</name>
    <message>
        <location filename="../../../batterywatcher.cpp" line="47"/>
        <source>No battery!</source>
        <translation>Nincs akku!</translation>
    </message>
    <message>
        <location filename="../../../batterywatcher.cpp" line="48"/>
        <source>LXQt could not find data about any battery - monitoring disabled</source>
        <translation>Az LXQt nem ismert fel akkut - figyelés tiltva</translation>
    </message>
    <message>
        <location filename="../../../batterywatcher.cpp" line="113"/>
        <source>Power low!</source>
        <translation>Alacsony feszültség!</translation>
    </message>
    <message numerus="yes">
        <location filename="../../../batterywatcher.cpp" line="125"/>
        <source>Suspending in %n second(s)</source>
        <translation>
            <numerusform>Készenlét %n másodperc múlva</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../../../batterywatcher.cpp" line="128"/>
        <source>Hibernating in %n second(s)</source>
        <translation>
            <numerusform>Mélykészenlét %n másodperc múlva</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../../../batterywatcher.cpp" line="131"/>
        <source>Shutting down in %n second(s)</source>
        <translation>
            <numerusform>Kikapcsolás %n másodperc múlva</numerusform>
        </translation>
    </message>
    <message>
        <source>Suspending in %1 seconds</source>
        <translation type="vanished">%1 másodperc múlva készülség</translation>
    </message>
    <message>
        <source>Hibernating in %1 seconds</source>
        <translation type="vanished">%1 másodperc múlva mélykészenlét</translation>
    </message>
    <message>
        <source>Shutting down in %1 seconds</source>
        <translation type="vanished">%1 másodperc múlva kikapcsolás</translation>
    </message>
</context>
<context>
    <name>IdlenessWatcher</name>
    <message>
        <source>LXQt Idleness watcher failed to start</source>
        <translation type="vanished">Az LXQt tétlenség figyelő indítása sikertelen</translation>
    </message>
    <message>
        <source>D-Bus interface org.freedesktop.ScreenSaver is already registered</source>
        <translation type="vanished">A D-Bus interface org.freedesktop.ScreenSaver imár regisztrálva van</translation>
    </message>
    <message>
        <source>The X11 Screensaver extension is not usable</source>
        <translation type="vanished">Az X11 képernyővédő bővítmény használhatatlan</translation>
    </message>
    <message>
        <source>Configure...</source>
        <translation type="vanished">Beállítás...</translation>
    </message>
    <message>
        <source>ERROR: Screen unlocked</source>
        <translation type="vanished">HIBA: A képernyő nem zárolt</translation>
    </message>
    <message>
        <source>Locking program &quot;%1&quot; exited with error code %2</source>
        <translation type="vanished">A&quot;%1&quot; zároló program %2 hibakóddal kilépett</translation>
    </message>
    <message>
        <source>Locking program &quot;%1&quot; crashed with error code %2</source>
        <translation type="vanished">A&quot;%1&quot; zároló program %2 hibakóddal összeomlott</translation>
    </message>
</context>
<context>
    <name>PowerManagementd</name>
    <message>
        <location filename="../../../powermanagementd.cpp" line="110"/>
        <source>Power Management</source>
        <translation>Energiakezelés</translation>
    </message>
    <message>
        <location filename="../../../powermanagementd.cpp" line="111"/>
        <source>You are running LXQt Power Management for the first time.
You can configure it from settings... </source>
        <translation>Az LXQt energiakezelő első alkalommal fut.
A beállításokban konfigurálható... </translation>
    </message>
    <message>
        <location filename="../../../powermanagementd.cpp" line="112"/>
        <source>Configure...</source>
        <translation>Beállítás...</translation>
    </message>
</context>
<context>
    <name>TrayIcon</name>
    <message>
        <location filename="../../../trayicon.cpp" line="59"/>
        <source>Configure</source>
        <translation>Beállítás</translation>
    </message>
    <message>
        <location filename="../../../trayicon.cpp" line="61"/>
        <location filename="../../../trayicon.cpp" line="92"/>
        <source>About</source>
        <translation>Rólunk</translation>
    </message>
    <message>
        <location filename="../../../trayicon.cpp" line="63"/>
        <source>Disable icon</source>
        <translation>Ikon tiltása</translation>
    </message>
    <message>
        <location filename="../../../trayicon.cpp" line="93"/>
        <source>&lt;p&gt;  &lt;b&gt;LXQt Power Management&lt;/b&gt;&lt;br/&gt;  - Power Management for the LXQt Desktop Environment&lt;/p&gt;&lt;p&gt;  Authors:&lt;br/&gt;  &amp;nbsp; Christian Surlykke, Alec Moskvin&lt;br/&gt;  &amp;nbsp; - and others from the Razor and LXQt projects&lt;/p&gt;&lt;p&gt;  Copyright &amp;copy; 2012-2014&lt;/p&gt;</source>
        <translation>&lt;p&gt;  &lt;b&gt;LXQt Power Management&lt;/b&gt;&lt;br/&gt;  - Energiakezelő az LXQt asztali környezethez&lt;/p&gt;&lt;p&gt;  Szerzők:&lt;br/&gt;  &amp;nbsp; Christian Surlykke, Alec Moskvin&lt;br/&gt;  &amp;nbsp; - és mások a Razor és LXQt csapatból&lt;/p&gt;&lt;p&gt;  Copyright &amp;copy; 2012-2014&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../../../trayicon.cpp" line="111"/>
        <source>LXQt Power Management info</source>
        <translation>LXQt Power Management infó</translation>
    </message>
    <message>
        <location filename="../../../trayicon.cpp" line="112"/>
        <source>The LXQt Power Management tray icon can be (re)enabled in &lt;i&gt;lxqt-config-powermanagement&lt;/i&gt;</source>
        <translation>Az LXQt energiakezelő tálcaikon (újra)engedélyezhető az &lt;i&gt;lxqt-config-powermanagement&lt;/i&gt; segítségével</translation>
    </message>
    <message>
        <location filename="../../../trayicon.cpp" line="114"/>
        <source>Configure now</source>
        <translation>Beállítás</translation>
    </message>
</context>
</TS>
